@@ -1,23 +1,15 @@
-# $Id: /mirror/perl/File-MMagic-XS/trunk/lib/File/MMagic/XS.pm 8591 2007-11-05T06:08:11.946493Z daisuke  $
-#
-# Copyright (c) 2005-2007 Daisuke Maki <daisuke@endeworks.jp>
-# All rights reserved.
-
 package File::MMagic::XS;
 use strict;
-use vars ('$VERSION', '$MAGIC_FILE');
+use warnings;
+use XSLoader;
+
+our $VERSION;
+our $MAGIC_FILE;
 
 BEGIN
 {
-    $VERSION = '0.09003';
-    if ($] > 5.006) {
-        require XSLoader;
-        XSLoader::load(__PACKAGE__, $VERSION);
-    } else {
-        require DynaLoader;
-        @File::MMagic::XS::ISA = ('DynaLoader');
-        __PACKAGE__->bootstrap();
-    }
+    $VERSION = '0.09004';
+    XSLoader::load(__PACKAGE__, $VERSION);
 
     require File::Spec;
     foreach my $path (map { File::Spec->catfile($_, qw(File MMagic magic)) } @INC) {
@@ -46,6 +38,15 @@ sub import
     $class->SUPER::import(@_);
 }
 
+sub new {
+    my ($class, $magic_file) = @_;
+    $magic_file ||= $MAGIC_FILE;
+
+    my $self = $class->create();
+    $self->parse_magic_file( $magic_file );
+    return $self;
+}
+
 1;
 
 __END__
@@ -100,6 +101,10 @@ If you specify the C<file> argument, then File::MMagic::XS will load magic
 definitions from the specified file. If unspecified, it will use the magic
 file that will be installed under File/MMagic/ directory.
 
+=head2 clone()
+
+Clones an existing File::MMagic::XS object.
+
 =head2 parse_magic_file($file)
 
 Read and parse a magic file, as used by Apache2.
